@@ -803,7 +803,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
 
         channel_id = self.get_channel(feed_slug)["id"]
 
-        url = self._base_url_ch+"/channels"+channel_id+"/messages"
+        url = self._base_url_ch+"/channels/"+channel_id+"/messages"
 
         s = requests.Session()
         s.keep_alive = False
